@@ -2,7 +2,7 @@
 //
 // as.h: Rcpp R/C++ interface class library -- convert SEXP to C++ objects
 //
-// Copyright (C) 2009 - 2010	Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2009 - 2011	Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -47,9 +47,9 @@ namespace internal{
 	}
 	
 	template <typename T> T as(SEXP x, ::Rcpp::traits::r_type_generic_tag ) throw(::Rcpp::not_compatible) {
-		RCPP_DEBUG( "as(SEXP = <%p>, r_type_generic_tag )", x ) ;
+		RCPP_DEBUG_1( "as(SEXP = <%p>, r_type_generic_tag )", x ) ;
 		::Rcpp::traits::Exporter<T> exporter(x);
-		RCPP_DEBUG( "exporter type = %s", DEMANGLE(exporter) ) ;
+		RCPP_DEBUG_1( "exporter type = %s", DEMANGLE(exporter) ) ;
 		return exporter.get() ;
 	}
 	
